NAME

Protocol::QUIC - Pure-Perl implementation of the QUIC Transport Protocol (RFC 9000, RFC 9001, RFC 9002)

VERSION

Version v0.0.1

DESCRIPTION

This is WIP, no code release yet, just to reserve the namesapce.

AUTHOR

Mohammad Sajid Anwar <mohammad.anwar@yahoo.com>

LICENSE AND COPYRIGHT

Copyright (C) 2026 Mohammad Sajid Anwar.

This program is free software; you can redistribute it and/or modify it under the terms of the Artistic License (2.0).